%bcond_with bootstrap

Name:           jsoup
Version:        1.18.1
Release:        %mkrel 1
Group:          Development/Java
Summary:        Java library for working with real-world HTML
License:        MIT
URL:            https://jsoup.org/
BuildArch:      noarch
#ExclusiveArch:  %%{java_arches} noarch

# ./generate-tarball.sh
Source0:        %{name}-%{version}.tar.gz
# The sources contain non-free scraped web pages as test data
Source1:        generate-tarball.sh

%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap
%else
BuildRequires:  maven-local
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-source-plugin)
%endif
BuildRequires:  jurand

%description
jsoup is a Java library for working with real-world HTML. It provides a very
convenient API for fetching URLs and extracting and manipulating data, using the
best of HTML5 DOM methods and CSS selectors.

jsoup implements the WHATWG HTML5 specification, and parses HTML to the same DOM
as modern browsers do.
* scrape and parse HTML from a URL, file, or string
* find and extract data, using DOM traversal or CSS selectors
* manipulate the HTML elements, attributes, and text
* clean user-submitted content against a safelist, to prevent XSS attacks
* output tidy HTML

jsoup is designed to deal with all varieties of HTML found in the wild; from
pristine and validating, to invalid tag-soup; jsoup will create a sensible parse
tree.

%{?javadoc_package}

%prep
%setup -q -n %{name}-%{name}-%{version}

%pom_remove_plugin :animal-sniffer-maven-plugin
%pom_remove_plugin :maven-failsafe-plugin
%pom_remove_plugin :maven-javadoc-plugin
%pom_remove_plugin com.github.siom79.japicmp:japicmp-maven-plugin

# Expose internal packages in the OSGi metadata, clearly marking them as such
# using the x-internal attribute
%pom_xpath_inject "pom:plugin[pom:artifactId='maven-bundle-plugin']/pom:configuration/pom:instructions" \
  "<_exportcontents>*.internal;x-internal:=true,*</_exportcontents>"

# Remove jspecify annotations which are used for static analysis only
%pom_remove_dep :jspecify
sed -i /org.jspecify/d src/main/java9/module-info.java
%java_remove_annotations src/main/java -s \
  -p org[.]jspecify[.]annotations[.] \

%build
%mvn_build -f

%install
%mvn_install

%files -f .mfiles
%doc README.md CHANGES.md
%license LICENSE




%changelog
* Mon Jul 15 2024 daviddavid <daviddavid> 1.18.1-1.mga10
+ Revision: 2081635
- Update to upstream version 1.18.1

* Wed May 22 2024 ns80 <ns80> 1.17.2-2.mga10
+ Revision: 2066166
- build without bootstrap

* Thu May 16 2024 ns80 <ns80> 1.17.2-1.mga10
+ Revision: 2064430
- bootstrap build
- new version 1.17.2 for modello 2.1.2

* Sat Mar 26 2022 umeabot <umeabot> 1.13.1-2.mga9
+ Revision: 1827562
- Mageia 9 Mass Rebuild

* Fri Sep 04 2020 daviddavid <daviddavid> 1.13.1-1.mga8
+ Revision: 1621821
- Update to version 1.13.1
- Expose internal packages in the OSGi metadata

* Tue Aug 11 2020 neoclust <neoclust> 1.12.1-1.mga8
+ Revision: 1613338
- New version 1.12.1

* Fri Feb 14 2020 umeabot <umeabot> 1.11.3-2.mga8
+ Revision: 1520784
- Mageia 8 Mass Rebuild

* Mon Dec 10 2018 daviddavid <daviddavid> 1.11.3-1.mga7
+ Revision: 1339799
- new version: 1.11.3 (sync with fc29)

* Thu Sep 20 2018 umeabot <umeabot> 1.11.2-2.mga7
+ Revision: 1279141
- Mageia 7 Mass Rebuild

* Thu Apr 12 2018 kekepower <kekepower> 1.11.2-1.mga7
+ Revision: 1217847
- Fix BuildRequires
- Remove online tests
- Update to version 1.11.2
+ neoclust <neoclust>
- Second rebuild of the java stack

* Tue Mar 01 2016 neoclust <neoclust> 1.8.3a-3.mga6
+ Revision: 981710
- First rebuild of the java stack
- sync package jsoup with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Sat Aug 29 2015 daviddavid <daviddavid> 1.8.3a-2.mga6
+ Revision: 870882
- fix owner of maven-poms dir and java dir

* Sat Aug 29 2015 daviddavid <daviddavid> 1.8.3a-1.mga6
+ Revision: 870850
- new version: 1.8.3a (fix CVE-2015-6748) (mga#16663)
- update Source URL
- remove animal-sniffer-maven-plugin (as it is not available)
- use %%license macro

* Sun Jan 18 2015 daviddavid <daviddavid> 1.7.2-4.mga5
+ Revision: 811321
- Sync with fc21

* Wed Oct 15 2014 umeabot <umeabot> 1.7.2-3.mga5
+ Revision: 746087
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Sun Jun 01 2014 dmorgan <dmorgan> 1.7.2-1.mga5
+ Revision: 630573
- New version

* Fri Oct 18 2013 umeabot <umeabot> 1.6.1-5.mga4
+ Revision: 506493
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 1.6.1-4.mga3
+ Revision: 355634
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jul 16 2012 dmorgan <dmorgan> 1.6.1-3.mga3
+ Revision: 271279
- Remove maven from requires
- imported package jsoup


* Fri Jul 22 2011 Jaromir Capik <jcapik@redhat.com> - 1.6.1-2
- Switching to sources from github

* Fri Jul 22 2011 Jaromir Capik <jcapik@redhat.com> - 1.6.1-1
- Initial package

